@@ -1,35 +1,30 @@
-/* SPDX-License-Identifier: LGPL-2.1-or-later */
+// SPDX-License-Identifier: LGPL-2.1-or-later
+#include "internal.h"
+
 #include <string.h>
 #include <errno.h>
 
-#include "internal.h"
-#include "fw_fcp.h"
-#include "hinawa_sigs_marshal.h"
-
 /**
- * SECTION:fw_fcp
- * @Title: HinawaFwFcp
- * @Short_description: A FCP transaction executor to a FireWire unit
- * @include: fw_fcp.h
+ * HinawaFwFcp:
+ * A FCP transaction executor to node in IEEE 1394 bus.
  *
  * A HinawaFwFcp supports Function Control Protocol (FCP) in IEC 61883-1, in which no way is defined
  * to match response against command by the contents of frames. In 'AV/C Digital Interface Command
  * Set General Specification Version 4.2' (Sep 1 2004, 1394TA), a pair of command and response is
- * loosely matched by the contents of frames. For convenience, HinawaFwFcp supports synchronous API
- * of command and response for AV/C specification.
+ * loosely matched by the contents of frames.
  *
- * Any of transaction frames should be aligned to 8bit (byte).
- * This class is an application of #HinawaFwReq / #HinawaFwResp.
+ * Any of transaction frames should be aligned to 8bit (byte). This class is an application of
+ * [class@FwReq] / [class@FwResp].
  */
 
 /**
  * hinawa_fw_fcp_error_quark:
  *
- * Return the GQuark for error domain of GError which has code in #HinawaFwFcpError.
+ * Return the [alias@GLib.Quark] for [struct@GLib.Error] which has code in Hinawa.FwFcpError.
  *
  * Since: 2.1
  *
- * Returns: A #GQuark.
+ * Returns: A [alias@GLib.Quark].
  */
 G_DEFINE_QUARK(hinawa-fw-fcp-error-quark, hinawa_fw_fcp_error)
 
@@ -38,8 +33,8 @@ static const char *const local_err_msgs[] = {
 	[HINAWA_FW_FCP_ERROR_LARGE_RESP]	= "The size of response is larger than expected",
 };
 
-#define generate_local_error(exception, code)						\
-	g_set_error_literal(exception, HINAWA_FW_FCP_ERROR, code, local_err_msgs[code])
+#define generate_local_error(error, code)						\
+	g_set_error_literal(error, HINAWA_FW_FCP_ERROR, code, local_err_msgs[code])
 
 #define FCP_MAXIMUM_FRAME_BYTES	0x200U
 #define FCP_REQUEST_ADDR	0xfffff0000b00
@@ -66,11 +61,11 @@ enum avc_status {
 	AVC_STATUS_INTERIM		= 0x0f,
 };
 
-struct _HinawaFwFcpPrivate {
+typedef struct {
 	HinawaFwNode *node;
 
 	guint timeout;
-};
+} HinawaFwFcpPrivate;
 G_DEFINE_TYPE_WITH_PRIVATE(HinawaFwFcp, hinawa_fw_fcp, HINAWA_TYPE_FW_RESP)
 
 /* This object has one property. */
@@ -150,7 +145,7 @@ static void hinawa_fw_fcp_class_init(HinawaFwFcpClass *klass)
 	 * HinawaFwFcp:timeout:
 	 *
 	 * Since 1.4
-	 * Deprecated: 2.1: Use timeout_ms parameter of #hinawa_fw_fcp_avc_transaction().
+	 * Deprecated: 2.1: Use timeout_ms parameter of [method@FwFcp.avc_transaction].
 	 */
 	fw_fcp_props[FW_FCP_PROP_TYPE_TIMEOUT] =
 		g_param_spec_uint("timeout", "timeout",
@@ -158,11 +153,13 @@ static void hinawa_fw_fcp_class_init(HinawaFwFcpClass *klass)
 				  "by msec unit.",
 				  10, G_MAXUINT,
 				  200,
-				  G_PARAM_READWRITE | G_PARAM_CONSTRUCT);
+				  G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_DEPRECATED);
 
 	/**
 	 * HinawaFwFcp:is-bound:
 	 *
+	 * Whether this protocol is bound to any instance of HinawaFwNode.
+	 *
 	 * Since: 2.0
 	 */
 	fw_fcp_props[FW_FCP_PROP_TYPE_IS_BOUND] =
@@ -178,15 +175,13 @@ static void hinawa_fw_fcp_class_init(HinawaFwFcpClass *klass)
 
         /**
          * HinawaFwFcp::responded:
-         * @self: A #HinawaFwFcp.
+         * @self: A [class@FwFcp].
          * @frame: (array length=frame_size)(element-type guint8): The array with elements for byte
-         *         data of response for Function Control Protocol.
+         *         data of response for FCP.
          * @frame_size: The number of elements of the array.
          *
-         * When the unit transfers asynchronous packet as response for Echo Audio Fireworks
-         * protocol, and the process successfully reads the content of packet from ALSA
-         * Fireworks driver, the #HinawaFwFcp::responded signal handler is called with parameters
-	 * of the response.
+	 * Emitted when the node transfers asynchronous packet as response for FCP and the process
+	 * successfully read the content of packet.
 	 *
 	 * Since: 2.1
          */
@@ -210,9 +205,9 @@ static void hinawa_fw_fcp_init(HinawaFwFcp *self)
 /**
  * hinawa_fw_fcp_new:
  *
- * Instantiate #HinawaFwFcp object and return the instance.
+ * Instantiate [class@FwFcp] object and return the instance.
  *
- * Returns: an instance of #HinawaFwFcp.
+ * Returns: an instance of [class@FwFcp].
  * Since: 1.3.
  */
 HinawaFwFcp *hinawa_fw_fcp_new(void)
@@ -222,21 +217,21 @@ HinawaFwFcp *hinawa_fw_fcp_new(void)
 
 /**
  * hinawa_fw_fcp_command:
- * @self: A #HinawaFwFcp.
+ * @self: A [class@FwFcp].
  * @cmd: (array length=cmd_size): An array with elements for request byte data. The value of this
  *	 argument should point to the array and immutable.
  * @cmd_size: The size of array for request in byte unit.
  * @timeout_ms: The timeout to wait for response subaction of transaction for command frame.
- * @exception: A #GError. Error can be generated with four domains; #hinawa_fw_node_error_quark(),
- *	       #hinawa_fw_req_error_quark().
+ * @error: A [struct@GLib.Error]. Error can be generated with four domains; Hinoko.FwNodeError and
+ *	   Hinoko.FwReqError.
  *
- * Transfer command frame for FCP. When receiving response frame for FCP,
- * #HinawaFwFcp::responded signal is emitted.
+ * Transfer command frame for FCP. When receiving response frame for FCP, [signal@FwFcp::responded]
+ * signal is emitted.
  *
  * Since: 2.1.
  */
 void hinawa_fw_fcp_command(HinawaFwFcp *self, const guint8 *cmd, gsize cmd_size,
-			   guint timeout_ms, GError **exception)
+			   guint timeout_ms, GError **error)
 {
 	HinawaFwFcpPrivate *priv;
 	HinawaFwReq *req;
@@ -244,7 +239,7 @@ void hinawa_fw_fcp_command(HinawaFwFcp *self, const guint8 *cmd, gsize cmd_size,
 	g_return_if_fail(HINAWA_IS_FW_FCP(self));
 	g_return_if_fail(cmd != NULL);
 	g_return_if_fail(cmd_size > 0 && cmd_size < FCP_MAXIMUM_FRAME_BYTES);
-	g_return_if_fail(exception == NULL || *exception == NULL);
+	g_return_if_fail(error == NULL || *error == NULL);
 
 	priv = hinawa_fw_fcp_get_instance_private(self);
 
@@ -253,7 +248,7 @@ void hinawa_fw_fcp_command(HinawaFwFcp *self, const guint8 *cmd, gsize cmd_size,
 	// Finish transaction for command frame.
 	hinawa_fw_req_transaction_sync(req, priv->node, HINAWA_FW_TCODE_WRITE_BLOCK_REQUEST,
 				       FCP_REQUEST_ADDR, cmd_size, (guint8 *const *)&cmd, &cmd_size,
-				       timeout_ms, exception);
+				       timeout_ms, error);
 	g_object_unref(req);
 }
 
@@ -284,7 +279,7 @@ static void handle_responded_signal(HinawaFwFcp *self, const guint8 *frame, guin
 
 /**
  * hinawa_fw_fcp_avc_transaction:
- * @self: A #HinawaFwFcp.
+ * @self: A [class@FwFcp].
  * @cmd: (array length=cmd_size)(in): An array with elements for request byte data. The value of
  *	 this argument should point to the array and immutable.
  * @cmd_size: The size of array for request in byte unit.
@@ -295,19 +290,20 @@ static void handle_responded_signal(HinawaFwFcp *self, const guint8 *frame, guin
  * @resp_size: The size of array for response in byte unit. The value of this argument should point to
  *	       the numerical number and mutable.
  * @timeout_ms: The timeout to wait for response transaction since command transactions finishes.
- * @exception: A #GError. Error can be generated with four domains; #hinawa_fw_node_error_quark(),
- *	       #hinawa_fw_req_error_quark(), and #hinawa_fw_fcp_error_quark().
+ * @error: A [struct@GLib.Error]. Error can be generated with four domains; Hinawa.FwNodeError,
+ *	   Hinawa.FwReqError, and Hinawa.FwFcpError.
  *
- * Finish the pair of AV/C command and response transactions. The timeout_ms parameter is
- * used to wait for response transaction since the command transaction is initiated, ignoring
- * #HinawaFwFcp:timeout property of instance. The timeout is not expanded in the case that AV/C
- * INTERIM status is arrived, thus the caller should expand the timeout in advance for the case.
+ * Finish the pair of asynchronous transaction for AV/C command and response transactions. The
+ * timeout_ms parameter is used to wait for response transaction since the command transaction is
+ * initiated, ignoring [property@FwFcp:timeout] property of instance. The timeout is not expanded in
+ * the case that AV/C INTERIM status is arrived, thus the caller should expand the timeout in
+ * advance for the case.
  *
  * Since: 2.1.
  */
 void hinawa_fw_fcp_avc_transaction(HinawaFwFcp *self, const guint8 *cmd, gsize cmd_size,
 				   guint8 *const *resp, gsize *resp_size, guint timeout_ms,
-				   GError **exception)
+				   GError **error)
 {
 	gulong handler_id;
 	struct waiter w = {0};
@@ -318,7 +314,7 @@ void hinawa_fw_fcp_avc_transaction(HinawaFwFcp *self, const guint8 *cmd, gsize c
 	g_return_if_fail(cmd_size > 2 && cmd_size < FCP_MAXIMUM_FRAME_BYTES);
 	g_return_if_fail(resp != NULL);
 	g_return_if_fail(resp_size != NULL && *resp_size > 0);
-	g_return_if_fail(exception == NULL || *exception == NULL);
+	g_return_if_fail(error == NULL || *error == NULL);
 
 	w.frame = *resp;
 	w.frame_size = *resp_size;
@@ -336,8 +332,8 @@ void hinawa_fw_fcp_avc_transaction(HinawaFwFcp *self, const guint8 *cmd, gsize c
 	g_mutex_lock(&w.mutex);
 
 	// Finish transaction for command frame.
-	hinawa_fw_fcp_command(self, cmd, cmd_size, timeout_ms, exception);
-	if (*exception)
+	hinawa_fw_fcp_command(self, cmd, cmd_size, timeout_ms, error);
+	if (*error)
 		goto end;
 deferred:
 	while (w.frame[0] == 0xff) {
@@ -347,7 +343,7 @@ deferred:
 	}
 
 	if (w.frame[0] == 0xff) {
-		generate_local_error(exception, HINAWA_FW_FCP_ERROR_TIMEOUT);
+		generate_local_error(error, HINAWA_FW_FCP_ERROR_TIMEOUT);
 	} else if (w.frame[0] == AVC_STATUS_INTERIM) {
 		// It's a deffered transaction, wait again.
 		w.frame[0] = 0x00;
@@ -356,7 +352,7 @@ deferred:
 		// use the finite value for safe.
 		goto deferred;
 	} else if (w.frame_size > *resp_size) {
-		generate_local_error(exception, HINAWA_FW_FCP_ERROR_LARGE_RESP);
+		generate_local_error(error, HINAWA_FW_FCP_ERROR_LARGE_RESP);
 	} else {
 		*resp_size = w.frame_size;
 	}
@@ -371,40 +367,38 @@ end:
 
 /**
  * hinawa_fw_fcp_transaction:
- * @self: A #HinawaFwFcp.
- * @req_frame: (array length=req_frame_size)(in): An array with elements for
- *	       request byte data. The value of this argument should point to
- *	       the array and immutable.
+ * @self: A [class@FwFcp].
+ * @req_frame: (array length=req_frame_size)(in): An array with elements for request byte data. The
+ *	       value of this argument should point to the array and immutable.
  * @req_frame_size: The size of array for request in byte unit.
- * @resp_frame: (array length=resp_frame_size)(inout): An array with elements
- *		for response byte data. Callers should give it for buffer with
- *		enough space against the request since this library performs no
- *		reallocation. Due to the reason, the value of this argument
- *		should point to the pointer to the array and immutable. The
- *		content of array is mutable.
- * @resp_frame_size: The size of array for response in byte unit. The value of
- *		     this argument should point to the numerical number and
- *		     mutable.
- * @exception: A #GError. Error can be generated with four domains; #hinawa_fw_node_error_quark(),
- *	       #hinawa_fw_req_error_quark(), and #hinawa_fw_fcp_error_quark().
+ * @resp_frame: (array length=resp_frame_size)(inout): An array with elements for response byte
+ *		data. Callers should give it for buffer with enough space against the request
+ *		since this library performs no reallocation. Due to the reason, the value of this
+ *		argument should point to the pointer to the array and immutable. The content of
+ *		array is mutable.
+ * @resp_frame_size: The size of array for response in byte unit. The value of this argument should
+ *		     point to the numerical number and mutable.
+ * @error: A [struct@GLib.Error]. Error can be generated with four domains; Hinawa.FwNodeError,
+ *	   Hinawa.FwReqError, and Hinawa.FwFcpError.
  *
- * Finish the pair of command and response transactions for FCP. The value of #HinawaFwFcp:timeout
- * property is used to wait for response transaction since the command transaction is initiated.
+ * Finish the pair of command and response transactions for FCP. The value of
+ * [property@FwFcp:timeout] property is used to wait for response transaction since the command
+ * transaction is initiated.
  *
  * Since: 1.4.
- * Deprecated: 2.1: Use #hinawa_fw_fcp_avc_transaction(), instead.
+ * Deprecated: 2.1: Use [method@FwFcp.avc_transaction], instead.
  */
 void hinawa_fw_fcp_transaction(HinawaFwFcp *self,
 			       const guint8 *req_frame, gsize req_frame_size,
 			       guint8 *const *resp_frame, gsize *resp_frame_size,
-			       GError **exception)
+			       GError **error)
 {
 	guint timeout_ms;
 
 	g_object_get(G_OBJECT(self), "timeout", &timeout_ms, NULL);
 
 	hinawa_fw_fcp_avc_transaction(self, req_frame, req_frame_size, resp_frame, resp_frame_size,
-				      timeout_ms, exception);
+				      timeout_ms, error);
 }
 
 static HinawaFwRcode handle_requested2_signal(HinawaFwResp *resp, HinawaFwTcode tcode, guint64 offset,
@@ -419,38 +413,37 @@ static HinawaFwRcode handle_requested2_signal(HinawaFwResp *resp, HinawaFwTcode
 	if (offset == FCP_RESPOND_ADDR && tcode == HINAWA_FW_TCODE_WRITE_BLOCK_REQUEST && src == node_id)
 		g_signal_emit(self, fw_fcp_sigs[FW_FCP_SIG_TYPE_RESPONDED], 0, frame, length);
 
-	// MEMO: Linux firewire subsystem already began respond transaction, thus the rcode is just
-	// ignored.
+	// MEMO: Linux firewire subsystem already send response subaction to finish the transaction,
+	// thus the rcode is just ignored.
 
 	return HINAWA_FW_RCODE_COMPLETE;
 }
 
 /**
  * hinawa_fw_fcp_bind:
- * @self: A #HinawaFwFcp.
- * @node: A #HinawaFwNode.
- * @exception: A #GError. Error can be generated with domain of #hinawa_fw_resp_error_quark().
+ * @self: A [class@FwFcp].
+ * @node: A [class@FwNode].
+ * @error: A [struct@GLib.Error]. Error can be generated with domain of Hinawa.FwFcpError.
  *
  * Start to listen to FCP responses.
  *
  * Since: 1.4
  */
-void hinawa_fw_fcp_bind(HinawaFwFcp *self, HinawaFwNode *node,
-			GError **exception)
+void hinawa_fw_fcp_bind(HinawaFwFcp *self, HinawaFwNode *node, GError **error)
 {
 	HinawaFwFcpPrivate *priv;
 
 	g_return_if_fail(HINAWA_IS_FW_FCP(self));
 	g_return_if_fail(node != NULL);
-	g_return_if_fail(exception == NULL || *exception == NULL);
+	g_return_if_fail(error == NULL || *error == NULL);
 
 	priv = hinawa_fw_fcp_get_instance_private(self);
 
 	if (priv->node == NULL) {
 		hinawa_fw_resp_reserve(HINAWA_FW_RESP(self), node,
 				FCP_RESPOND_ADDR, FCP_MAXIMUM_FRAME_BYTES,
-				exception);
-		if (*exception != NULL)
+				error);
+		if (*error != NULL)
 			return;
 		priv->node = g_object_ref(node);
 	}
@@ -458,7 +451,7 @@ void hinawa_fw_fcp_bind(HinawaFwFcp *self, HinawaFwNode *node,
 
 /**
  * hinawa_fw_fcp_unbind:
- * @self: A #HinawaFwFcp.
+ * @self: A [class@FwFcp].
  *
  * Stop to listen to FCP responses.
  *
