@@ -1,4 +1,4 @@
-/* SPDX-License-Identifier: LGPL-2.1-or-later */
+// SPDX-License-Identifier: LGPL-2.1-or-later
 #include "internal.h"
 
 #include <sys/types.h>
@@ -8,17 +8,13 @@
 #include <sys/ioctl.h>
 #include <errno.h>
 
-#include <linux/firewire-cdev.h>
-
 /**
- * SECTION:fw_node
- * @Title: HinawaFwNode
- * @Short_description: An event listener for FireWire node
- * @include: fw_node.h
+ * HinawaFwNode:
+ * An event listener for FireWire node
  *
- * A #HinawaFwNode is an event listener for a specified node on IEEE 1394 bus.
- * This class is an application of Linux FireWire subsystem.
- * All of operations utilize ioctl(2) with subsystem specific request commands.
+ * A [class@FwNode] is an event listener for a specified node on IEEE 1394 bus. This class is an
+ * application of Linux FireWire subsystem. All of operations utilize ioctl(2) with subsystem
+ * specific request commands.
  *
  * Since: 1.4.
  */
@@ -29,7 +25,7 @@
 #define MAX_CONFIG_ROM_SIZE	256
 #define MAX_CONFIG_ROM_LENGTH	(MAX_CONFIG_ROM_SIZE * 4)
 
-struct _HinawaFwNodePrivate {
+typedef struct {
 	int fd;
 
 	GMutex mutex;
@@ -39,18 +35,17 @@ struct _HinawaFwNodePrivate {
 
 	GList *transactions;
 	GMutex transactions_mutex;
-};
-
+} HinawaFwNodePrivate;
 G_DEFINE_TYPE_WITH_PRIVATE(HinawaFwNode, hinawa_fw_node, G_TYPE_OBJECT)
 
 /**
  * hinawa_fw_node_error_quark:
  *
- * Return the GQuark for error domain of GError which has code in #HinawaFwNodeError.
+ * Return the [alias@GLib.Quark] for [struct@GLib.Error] with Hinawa.FwNodeError domain.
  *
  * Since: 2.1
  *
- * Returns: A #GQuark.
+ * Returns: A [alias@GLib.Quark].
  */
 G_DEFINE_QUARK(hinawa-fw-node-error-quark, hinawa_fw_node_error)
 
@@ -60,14 +55,14 @@ static const char *const err_msgs[] = {
 	[HINAWA_FW_NODE_ERROR_NOT_OPENED] = "The instance is not associated to node",
 };
 
-#define generate_local_error(exception, code) \
-	g_set_error_literal(exception, HINAWA_FW_NODE_ERROR, code, err_msgs[code])
+#define generate_local_error(error, code) \
+	g_set_error_literal(error, HINAWA_FW_NODE_ERROR, code, err_msgs[code])
 
-#define generate_file_error(exception, code, format, arg) \
-	g_set_error(exception, G_FILE_ERROR, code, format, arg)
+#define generate_file_error(error, code, format, arg) \
+	g_set_error(error, G_FILE_ERROR, code, format, arg)
 
-#define generate_syscall_error(exception, errno, format, arg)				\
-	g_set_error(exception, HINAWA_FW_NODE_ERROR, HINAWA_FW_NODE_ERROR_FAILED,	\
+#define generate_syscall_error(error, errno, format, arg)				\
+	g_set_error(error, HINAWA_FW_NODE_ERROR, HINAWA_FW_NODE_ERROR_FAILED,	\
 		    format " %d(%s)", arg, errno, strerror(errno))
 
 typedef struct {
@@ -155,6 +150,9 @@ static void hinawa_fw_node_class_init(HinawaFwNodeClass *klass)
 	/**
 	 * HinawaFwNode:node-id:
 	 *
+	 * Node ID of node associated to instance of object at current generation of bus topology.
+	 * This parameter is effective after the association.
+	 *
 	 * Since: 1.4
 	 */
 	fw_node_props[FW_NODE_PROP_TYPE_NODE_ID] =
@@ -168,6 +166,9 @@ static void hinawa_fw_node_class_init(HinawaFwNodeClass *klass)
 	/**
 	 * HinawaFwNode:local-node-id:
 	 *
+	 * Node ID of node which application uses to communicate to node associated to instance of
+	 * object at current generation of bus topology. In general, it is for 1394 OHCI controller.
+	 *
 	 * Since: 1.4
 	 */
 	fw_node_props[FW_NODE_PROP_TYPE_LOCAL_NODE_ID] =
@@ -181,6 +182,8 @@ static void hinawa_fw_node_class_init(HinawaFwNodeClass *klass)
 	/**
 	 * HinawaFwNode:bus-manager-node-id:
 	 *
+	 * Node ID of node which plays role of bus manager at current generation of bus topology.
+	 *
 	 * Since: 1.4
 	 */
 	fw_node_props[FW_NODE_PROP_TYPE_BUS_MANAGER_NODE_ID] =
@@ -193,6 +196,9 @@ static void hinawa_fw_node_class_init(HinawaFwNodeClass *klass)
 	/**
 	 * HinawaFwNode:ir-manager-node-id:
 	 *
+	 * Node ID of node which plays role of isochronous resource manager at current generation
+	 * of bus topology.
+	 *
 	 * Since: 1.4
 	 */
 	fw_node_props[FW_NODE_PROP_TYPE_IR_MANAGER_NODE_ID] =
@@ -205,6 +211,8 @@ static void hinawa_fw_node_class_init(HinawaFwNodeClass *klass)
 	/**
 	 * HinawaFwNode:root-node-id:
 	 *
+	 * Node ID of root node in bus topology at current generation of the bus topology.
+	 *
 	 * Since: 1.4
 	 */
 	fw_node_props[FW_NODE_PROP_TYPE_ROOT_NODE_ID] =
@@ -217,6 +225,8 @@ static void hinawa_fw_node_class_init(HinawaFwNodeClass *klass)
 	/**
 	 * HinawaFwNode:generation:
 	 *
+	 * Current generation of bus topology.
+	 *
 	 * Since: 1.4
 	 */
 	fw_node_props[FW_NODE_PROP_TYPE_GENERATION] =
@@ -231,11 +241,10 @@ static void hinawa_fw_node_class_init(HinawaFwNodeClass *klass)
 
 	/**
 	 * HinawaFwNode::bus-update:
-	 * @self: A #HinawaFwNode.
+	 * @self: A [class@FwNode].
 	 *
-	 * When IEEE 1394 bus is updated, the #HinawaFwNode::bus-update signal is generated.
-	 * Handlers can read current generation in the bus via 'generation'
-	 * property.
+	 * Emitted when IEEE 1394 bus is updated. Handlers can read current generation in the bus
+	 * via [property@FwNode:generation] property.
 	 *
 	 * Since: 1.4
 	 */
@@ -250,10 +259,10 @@ static void hinawa_fw_node_class_init(HinawaFwNodeClass *klass)
 
 	/**
 	 * HinawaFwNode::disconnected:
-	 * @self: A #HinawaFwNode.
+	 * @self: A [class@FwNode].
 	 *
-	 * When phicical FireWire devices are disconnected from IEEE 1394 bus,
-	 * the #HinawaFwNode::disconnected signal is generated.
+	 * Emitted when the node is not available anymore due to removal from IEEE 1394 bus. It's
+	 * preferable to call [method@GObject.Object.unref] immediately to release file descriptor.
 	 *
 	 * Since: 1.4
 	 */
@@ -279,9 +288,9 @@ static void hinawa_fw_node_init(HinawaFwNode *self)
 /**
  * hinawa_fw_node_new:
  *
- * Instantiate #HinawaFwNode object and return the instance.
+ * Instantiate [class@FwNode] object and return the instance.
  *
- * Returns: an instance of #HinawaFwNode.
+ * Returns: an instance of [class@FwNode].
  * Since: 1.4.
  */
 HinawaFwNode *hinawa_fw_node_new(void)
@@ -319,41 +328,41 @@ static int update_info(HinawaFwNode *self)
 
 /**
  * hinawa_fw_node_open:
- * @self: A #HinawaFwNode
+ * @self: A [class@FwNode]
  * @path: A path to Linux FireWire character device
- * @exception: A #GError. Error can be generated with two domains; #g_file_error_quark(), and
- *	       #hinawa_fw_node_error_quark().
+ * @error: A [struct@GLib.Error]. Error can be generated with two domains; GLib.Error and
+ *	   Hinawa.FwNodeError.
  *
  * Open Linux FireWire character device to operate node on IEEE 1394 bus.
  *
  * Since: 1.4.
  */
 void hinawa_fw_node_open(HinawaFwNode *self, const gchar *path,
-			 GError **exception)
+			 GError **error)
 {
 	HinawaFwNodePrivate *priv;
 	int err;
 
 	g_return_if_fail(HINAWA_IS_FW_NODE(self));
 	g_return_if_fail(path != NULL && strlen(path) > 0);
-	g_return_if_fail(exception == NULL || *exception == NULL);
+	g_return_if_fail(error == NULL || *error == NULL);
 
 	priv = hinawa_fw_node_get_instance_private(self);
 	if (priv->fd >= 0) {
-		generate_local_error(exception, HINAWA_FW_NODE_ERROR_OPENED);
+		generate_local_error(error, HINAWA_FW_NODE_ERROR_OPENED);
 		return;
 	}
 
 	priv->fd = open(path, O_RDONLY);
 	if (priv->fd < 0) {
 		if (errno == ENODEV) {
-			generate_local_error(exception, HINAWA_FW_NODE_ERROR_DISCONNECTED);
+			generate_local_error(error, HINAWA_FW_NODE_ERROR_DISCONNECTED);
 		} else {
 			GFileError code = g_file_error_from_errno(errno);
 			if (code != G_FILE_ERROR_FAILED)
-				generate_file_error(exception, code, "open(%s)", path);
+				generate_file_error(error, code, "open(%s)", path);
 			else
-				generate_syscall_error(exception, errno, "open(%s)", path);
+				generate_syscall_error(error, errno, "open(%s)", path);
 		}
 		return;
 	}
@@ -364,9 +373,9 @@ void hinawa_fw_node_open(HinawaFwNode *self, const gchar *path,
 
 	if (err > 0) {
 		if (err == ENODEV)
-			generate_local_error(exception, HINAWA_FW_NODE_ERROR_DISCONNECTED);
+			generate_local_error(error, HINAWA_FW_NODE_ERROR_DISCONNECTED);
 		else
-			generate_syscall_error(exception, errno, "ioctl(%s)", "FW_CDEV_IOC_GET_INFO");
+			generate_syscall_error(error, errno, "ioctl(%s)", "FW_CDEV_IOC_GET_INFO");
 		close(priv->fd);
 		priv->fd = -1;
 	}
@@ -374,30 +383,29 @@ void hinawa_fw_node_open(HinawaFwNode *self, const gchar *path,
 
 /**
  * hinawa_fw_node_get_config_rom:
- * @self: A #HinawaFwNode
- * @image: (array length=length)(out)(transfer none): The content of
- *	   configuration ROM.
+ * @self: A [class@FwNode]
+ * @image: (array length=length)(out)(transfer none): The content of configuration ROM.
  * @length: (out): The number of bytes consists of the configuration rom.
- * @exception: A #GError.
+ * @error: A [struct@GLib.Error].
  *
  * Get cached content of configuration ROM aligned to big-endian.
  *
  * Since: 1.4.
  */
 void hinawa_fw_node_get_config_rom(HinawaFwNode *self, const guint8 **image,
-				   gsize *length, GError **exception)
+				   gsize *length, GError **error)
 {
 	HinawaFwNodePrivate *priv;
 
 	g_return_if_fail(HINAWA_IS_FW_NODE(self));
 	g_return_if_fail(image != NULL);
 	g_return_if_fail(length != NULL);
-	g_return_if_fail(exception == NULL || *exception == NULL);
+	g_return_if_fail(error == NULL || *error == NULL);
 
 
 	priv = hinawa_fw_node_get_instance_private(self);
 	if (priv->fd < 0) {
-		generate_local_error(exception, HINAWA_FW_NODE_ERROR_NOT_OPENED);
+		generate_local_error(error, HINAWA_FW_NODE_ERROR_NOT_OPENED);
 		return;
 	}
 
@@ -428,7 +436,7 @@ static gboolean check_src(GSource *gsrc)
 	FwNodeSource *src = (FwNodeSource *)gsrc;
 	GIOCondition condition;
 
-	// Don't go to dispatch if nothing available. As an exception, return
+	// Don't go to dispatch if nothing available. As an error, return
 	// TRUE for POLLERR to call .dispatch for internal destruction.
 	condition = g_source_query_unix_fd(gsrc, src->tag);
 	return !!(condition & (G_IO_IN | G_IO_ERR));
@@ -463,14 +471,14 @@ static gboolean dispatch_src(GSource *gsrc, GSourceFunc cb, gpointer user_data)
 
 	common = (struct fw_cdev_event_common *)src->buf;
 
-	if (HINAWA_IS_FW_NODE(common->closure) && common->type == FW_CDEV_EVENT_BUS_RESET) {
+	if (HINAWA_IS_FW_NODE((gpointer)common->closure) && common->type == FW_CDEV_EVENT_BUS_RESET) {
 		handle_update(src->self);
-	} else if (HINAWA_IS_FW_RESP(common->closure) && common->type == FW_CDEV_EVENT_REQUEST2) {
-		hinawa_fw_resp_handle_request(HINAWA_FW_RESP(common->closure),
+	} else if (HINAWA_IS_FW_RESP((gpointer)common->closure) && common->type == FW_CDEV_EVENT_REQUEST2) {
+		hinawa_fw_resp_handle_request(HINAWA_FW_RESP((gpointer)common->closure),
 				(struct fw_cdev_event_request2 *)common);
-	} else if (HINAWA_IS_FW_REQ(common->closure) && common->type == FW_CDEV_EVENT_RESPONSE) {
+	} else if (HINAWA_IS_FW_REQ((gpointer)common->closure) && common->type == FW_CDEV_EVENT_RESPONSE) {
 		struct fw_cdev_event_response *ev = (struct fw_cdev_event_response *)common;
-		HinawaFwReq *req = HINAWA_FW_REQ(ev->closure);
+		HinawaFwReq *req = HINAWA_FW_REQ((gpointer)ev->closure);
 		GList *entry;
 
 		// Don't process request invalidated in advance.
@@ -496,18 +504,17 @@ static void finalize_src(GSource *gsrc)
 
 /**
  * hinawa_fw_node_create_source:
- * @self: A #HinawaFwNode.
- * @gsrc: (out): A #GSource.
- * @exception: A #GError. Error can be generated with domain of #hinawa_fw_node_error_quark()
- *	       and code of #HinawaFwNodeError.
+ * @self: A [class@FwNode].
+ * @gsrc: (out): A [struct@GLib.Source].
+ * @error: A [struct@GLib.Error]. Error can be generated with domain of Hinawa.FwNodeError.
  *
- * Create Gsource for GMainContext to dispatch events for the node on IEEE 1394
- * bus.
+ * Create [struct@GLib.Source] for [struct@GLib.MainContext] to dispatch events for the node on
+ * IEEE 1394 bus.
  *
  * Since: 1.4.
  */
 void hinawa_fw_node_create_source(HinawaFwNode *self, GSource **gsrc,
-				  GError **exception)
+				  GError **error)
 {
         static GSourceFuncs funcs = {
                 .check          = check_src,
@@ -519,11 +526,11 @@ void hinawa_fw_node_create_source(HinawaFwNode *self, GSource **gsrc,
 
 	g_return_if_fail(HINAWA_IS_FW_NODE(self));
 	g_return_if_fail(gsrc != NULL);
-	g_return_if_fail(exception == NULL || *exception == NULL);
+	g_return_if_fail(error == NULL || *error == NULL);
 
 	priv = hinawa_fw_node_get_instance_private(self);
 	if (priv->fd < 0) {
-		generate_local_error(exception, HINAWA_FW_NODE_ERROR_NOT_OPENED);
+		generate_local_error(error, HINAWA_FW_NODE_ERROR_NOT_OPENED);
 		return;
 	}
 
@@ -531,8 +538,6 @@ void hinawa_fw_node_create_source(HinawaFwNode *self, GSource **gsrc,
 	src = (FwNodeSource *)(*gsrc);
 
         g_source_set_name(*gsrc, "HinawaFwNode");
-        g_source_set_priority(*gsrc, G_PRIORITY_HIGH_IDLE);
-        g_source_set_can_recurse(*gsrc, TRUE);
 
         // MEMO: allocate one page because we cannot assume the size of
         // transaction frame.
@@ -544,16 +549,16 @@ void hinawa_fw_node_create_source(HinawaFwNode *self, GSource **gsrc,
 }
 
 // Internal use only.
-int hinawa_fw_node_ioctl(HinawaFwNode *self, unsigned long req, void *args, GError **exception)
+int hinawa_fw_node_ioctl(HinawaFwNode *self, unsigned long req, void *args, GError **error)
 {
 	HinawaFwNodePrivate *priv;
 
 	g_return_val_if_fail(HINAWA_IS_FW_NODE(self), ENXIO);
-	g_return_val_if_fail(exception != NULL, EINVAL);
+	g_return_val_if_fail(error != NULL, EINVAL);
 
 	priv = hinawa_fw_node_get_instance_private(self);
 	if (priv->fd < 0) {
-		generate_local_error(exception, HINAWA_FW_NODE_ERROR_NOT_OPENED);
+		generate_local_error(error, HINAWA_FW_NODE_ERROR_NOT_OPENED);
 		return ENXIO;
 	}
 
@@ -566,7 +571,7 @@ int hinawa_fw_node_ioctl(HinawaFwNode *self, unsigned long req, void *args, GErr
 
 	if (ioctl(priv->fd, req, args) < 0) {
 		if (errno == ENODEV)
-			generate_local_error(exception, HINAWA_FW_NODE_ERROR_DISCONNECTED);
+			generate_local_error(error, HINAWA_FW_NODE_ERROR_DISCONNECTED);
 		return errno;
 	}
 
