@@ -1,32 +1,29 @@
-/* SPDX-License-Identifier: LGPL-2.1-or-later */
+// SPDX-License-Identifier: LGPL-2.1-or-later
+#include "internal.h"
+
 #include <string.h>
 #include <errno.h>
 #include <sys/ioctl.h>
 
-#include "internal.h"
-#include "hinawa_sigs_marshal.h"
-#include "hinawa_enums.h"
-
 /**
- * SECTION:fw_resp
- * @Title: HinawaFwResp
- * @Short_description: A transaction responder for a FireWire node.
- * @include: fw_resp.h
+ * HinawaFwResp:
+ * A transaction responder for request initiated by node in IEEE 1394 bus.
  *
- * A HinawaFwResp responds requests from any units.
+ * The [class@FwResp] responds transaction initiated by node in IEEE 1394 bus.
  *
- * This class is an application of Linux FireWire subsystem. All of operations
- * utilize ioctl(2) with subsystem specific request commands.
+ * This class is an application of Linux FireWire subsystem. All of operations utilize ioctl(2)
+ * with subsystem specific request commands.
  */
 
 /**
  * hinawa_fw_resp_error_quark:
  *
- * Return the GQuark for error domain of GError which has code in #HinawaFwRespError.
+ * Return the [alias@GLib.Quark] for error domain of [struct@GLib.Error] which has code in
+ * Hinawa.FwRespError.
  *
  * Since: 2.2
  *
- * Returns: A #GQuark.
+ * Returns: A [alias@GLib.Quark].
  */
 G_DEFINE_QUARK(hinawa-fw-resp-error-quark, hinawa_fw_resp_error)
 
@@ -35,14 +32,14 @@ static const char *const err_msgs[] = {
 	[HINAWA_FW_RESP_ERROR_ADDR_SPACE_USED] = "The requested range of address is already used exclusively",
 };
 
-#define generate_local_error(exception, code) \
-	g_set_error_literal(exception, HINAWA_FW_RESP_ERROR, code, err_msgs[code])
+#define generate_local_error(error, code) \
+	g_set_error_literal(error, HINAWA_FW_RESP_ERROR, code, err_msgs[code])
 
-#define generate_syscall_error(exception, errno, format, arg)				\
-	g_set_error(exception, HINAWA_FW_RESP_ERROR, HINAWA_FW_RESP_ERROR_FAILED,	\
+#define generate_syscall_error(error, errno, format, arg)			\
+	g_set_error(error, HINAWA_FW_RESP_ERROR, HINAWA_FW_RESP_ERROR_FAILED,	\
 		    format " %d(%s)", arg, errno, strerror(errno))
 
-struct _HinawaFwRespPrivate {
+typedef struct {
 	HinawaFwNode *node;
 
 	guint64 offset;
@@ -53,7 +50,7 @@ struct _HinawaFwRespPrivate {
 	gsize req_length;
 	guint8 *resp_frame;
 	gsize resp_length;
-};
+} HinawaFwRespPrivate;
 G_DEFINE_TYPE_WITH_PRIVATE(HinawaFwResp, hinawa_fw_resp, G_TYPE_OBJECT)
 
 // This object has one property.
@@ -114,6 +111,8 @@ static void hinawa_fw_resp_class_init(HinawaFwRespClass *klass)
 	/**
 	 * HinawaFwResp:is-reserved:
 	 *
+	 * Whether a range of address is reserved or not in host controller.
+	 *
 	 * Since: 2.0
 	 */
 	fw_resp_props[FW_RESP_PROP_TYPE_IS_RESERVED] =
@@ -126,6 +125,8 @@ static void hinawa_fw_resp_class_init(HinawaFwRespClass *klass)
 	/**
 	 * HinawaFwResp:offset:
 	 *
+	 * The start offset of reserved address range.
+	 *
 	 * Since: 2.3
 	 */
 	fw_resp_props[FW_RESP_PROP_TYPE_OFFSET] =
@@ -138,6 +139,8 @@ static void hinawa_fw_resp_class_init(HinawaFwRespClass *klass)
 	/**
 	 * HinawaFwResp:width:
 	 *
+	 * The width of reserved address range.
+	 *
 	 * Since: 2.3
 	 */
 	fw_resp_props[FW_RESP_PROP_TYPE_WIDTH] =
@@ -153,26 +156,27 @@ static void hinawa_fw_resp_class_init(HinawaFwRespClass *klass)
 
 	/**
 	 * HinawaFwResp::requested:
-	 * @self: A #HinawaFwResp
-	 * @tcode: One of #HinawaTcode enumerators
+	 * @self: A [class@FwResp]
+	 * @tcode: One of [enum@FwTcode] enumerations.
 	 *
-	 * When any node transfers requests to the range of address to which this object listening,
-	 * the #HinawaFwResp::requested signal handler is called with #HinawaFwTcode, without the
-	 * case that #HinawaFwResp::requested2 signal handler is already assigned.
+	 * Emitted when any node transfers requests to the range of address to which this object
+	 * listening, the [signal@FwResp::requested] signal handler is called with [enum@FwTcode],
+	 * without the case that [signal@FwResp::requested2] signal handler is already assigned.
 	 *
-	 * The handler can get data frame by a call of #hinawa_fw_resp_get_req_frame() and set data
-	 * frame by a call of #hinawa_fw_resp_set_resp_frame(), then returns rcode.
+	 * The handler can get data frame by a call of [method@FwResp.get_req_frame] and set data
+	 * frame by a call of [method@FwResp.set_resp_frame], then returns [enum@FwRcode] for
+	 * response subaction.
 	 *
-	 * Returns: One of #HinawaRcode enumerators corresponding to rcodes defined in IEEE 1394
-	 * specification.
+	 * Returns: One of [enum@FwRcode] enumerations corresponding to rcodes defined in IEEE 1394
+	 *	    specification.
 	 *
 	 * Since: 0.3
-	 * Deprecated: 2.2: Use #HinawaFwResp::requested2, instead.
+	 * Deprecated: 2.2: Use [signal@FwResp::requested2], instead.
 	 */
 	fw_resp_sigs[FW_RESP_SIG_TYPE_REQ] =
 		g_signal_new("requested",
 			     G_OBJECT_CLASS_TYPE(klass),
-			     G_SIGNAL_RUN_LAST,
+			     G_SIGNAL_RUN_LAST | G_SIGNAL_DEPRECATED,
 			     G_STRUCT_OFFSET(HinawaFwRespClass, requested),
 			     NULL, NULL,
 			     hinawa_sigs_marshal_ENUM__ENUM,
@@ -180,8 +184,8 @@ static void hinawa_fw_resp_class_init(HinawaFwRespClass *klass)
 
 	/**
 	 * HinawaFwResp::requested2:
-	 * @self: A #HinawaFwResp
-	 * @tcode: One of #HinawaTcode enumerations
+	 * @self: A [class@FwResp]
+	 * @tcode: One of [enum@FwTcode] enumerations
 	 * @offset: The address offset at which the transaction arrives.
 	 * @src: The node ID of source for the transaction.
 	 * @dst: The node ID of destination for the transaction.
@@ -191,12 +195,12 @@ static void hinawa_fw_resp_class_init(HinawaFwRespClass *klass)
 	 *	   data.
 	 * @length: The length of bytes for the frame.
 	 *
-	 * When any node transfers request subaction to the range of address to which this object
-	 * listening, the #HinawaFwResp::requested signal handler is called with arrived frame for
-	 * the subaction. The handler is expected to call #hinawa_fw_resp_set_resp_frame() with
-	 * frame and return rcode for response subaction.
+	 * Emitted when any node transfers request subaction to the range of address to which this
+	 * object listening, the [signal@FwResp::requested] signal handler is called with arrived
+	 * frame for the subaction. The handler is expected to call [method@FwResp.set_resp_frame]
+	 * with frame and return [enum@FwRcode] for response subaction.
 	 *
-	 * Returns: One of #HinawaRcode enumerators corresponding to rcodes defined in IEEE 1394
+	 * Returns: One of [enum@FwRcode] enumerations corresponding to rcodes defined in IEEE 1394
 	 *	    specification.
 	 * Since: 2.2
 	 */
@@ -220,9 +224,9 @@ static void hinawa_fw_resp_init(HinawaFwResp *self)
 /**
  * hinawa_fw_resp_new:
  *
- * Instantiate #HinawaFwResp object and return the instance.
+ * Instantiate [class@FwResp] object and return the instance.
  *
- * Returns: a new instance of #HinawaFwResp.
+ * Returns: a new instance of [class@FwResp].
  * Since: 1.3.
  */
 HinawaFwResp *hinawa_fw_resp_new(void)
@@ -232,23 +236,23 @@ HinawaFwResp *hinawa_fw_resp_new(void)
 
 /**
  * hinawa_fw_resp_reserve_within_region:
- * @self: A #HinawaFwResp.
- * @node: A #HinawaFwNode.
+ * @self: A [class@FwResp].
+ * @node: A [class@FwNode].
  * @region_start:  Start offset of address region in which range of address is looked up.
  * @region_end:  End offset of address region in which range of address is looked up.
  * @width: The width for range of address to be looked up.
- * @exception: A #GError. Error can be generated with two domain of #hinawa_fw_node_error_quark()
- *	       and #hinawa_fw_resp_error_quark().
+ * @error: A [struct@GLib.Error]. Error can be generated with two domain of Hinawa.FwNodeError and
+ *	   Hinawa.FwRespError.
  *
  * Start to listen to range of address equals to #width in local node (e.g. 1394 OHCI host
  * controller), which is used to communicate to the node given as parameter. The range of address
- * is looked up in region between #region_start and #region_end.
+ * is looked up in region between region_start and region_end.
  *
  * Since: 2.3.
  */
 void hinawa_fw_resp_reserve_within_region(HinawaFwResp *self, HinawaFwNode *node,
 					  guint64 region_start, guint64 region_end, guint width,
-					  GError **exception)
+					  GError **error)
 {
 	HinawaFwRespPrivate *priv;
 	struct fw_cdev_allocate allocate = {0};
@@ -256,11 +260,11 @@ void hinawa_fw_resp_reserve_within_region(HinawaFwResp *self, HinawaFwNode *node
 
 	g_return_if_fail(HINAWA_IS_FW_RESP(self));
 	g_return_if_fail(width > 0);
-	g_return_if_fail(exception == NULL || *exception == NULL);
+	g_return_if_fail(error == NULL || *error == NULL);
 
 	priv = hinawa_fw_resp_get_instance_private(self);
 	if (priv->node != NULL) {
-		generate_local_error(exception, HINAWA_FW_RESP_ERROR_RESERVED);
+		generate_local_error(error, HINAWA_FW_RESP_ERROR_RESERVED);
 		return;
 	}
 
@@ -269,14 +273,14 @@ void hinawa_fw_resp_reserve_within_region(HinawaFwResp *self, HinawaFwNode *node
 	allocate.length = width;
 	allocate.region_end = region_end;
 
-	err = hinawa_fw_node_ioctl(node, FW_CDEV_IOC_ALLOCATE, &allocate, exception);
-	if (*exception != NULL)
+	err = hinawa_fw_node_ioctl(node, FW_CDEV_IOC_ALLOCATE, &allocate, error);
+	if (*error != NULL)
 		return;
 	if (err > 0) {
 		if (err == EBUSY)
-			generate_local_error(exception, HINAWA_FW_RESP_ERROR_ADDR_SPACE_USED);
+			generate_local_error(error, HINAWA_FW_RESP_ERROR_ADDR_SPACE_USED);
 		else
-			generate_syscall_error(exception, err, "ioctl(%s)", "FW_CDEV_IOC_ALLOCATE");
+			generate_syscall_error(error, err, "ioctl(%s)", "FW_CDEV_IOC_ALLOCATE");
 		return;
 	}
 
@@ -293,30 +297,30 @@ void hinawa_fw_resp_reserve_within_region(HinawaFwResp *self, HinawaFwNode *node
 
 /**
  * hinawa_fw_resp_reserve:
- * @self: A #HinawaFwResp.
- * @node: A #HinawaFwNode.
+ * @self: A [class@FwResp].
+ * @node: A [class@FwNode].
  * @addr: A start address to listen to in host controller.
  * @width: The byte width of address to listen to host controller.
- * @exception: A #GError. Error can be generated with two domain of #hinawa_fw_node_error_quark()
- *	       and #hinawa_fw_resp_error_quark().
+ * @error: A [struct@GLib.Error]. Error can be generated with two domain of Hinawa.FwNodeError and
+ *	   and Hinawa.FwRespError.
  *
  * Start to listen to a range of address in host controller which connects to the node. The function
- * is a variant of #hinawa_fw_resp_reserve_within_region() so that the exact range of address should
+ * is a variant of [method@FwResp.reserve_within_region] so that the exact range of address should
  * be reserved as given.
  *
  * Since: 1.4.
  */
 void hinawa_fw_resp_reserve(HinawaFwResp *self, HinawaFwNode *node,
-			    guint64 addr, guint width, GError **exception)
+			    guint64 addr, guint width, GError **error)
 {
-	hinawa_fw_resp_reserve_within_region(self, node, addr, addr + width, width, exception);
+	hinawa_fw_resp_reserve_within_region(self, node, addr, addr + width, width, error);
 }
 
 /**
  * hinawa_fw_resp_release:
- * @self: A HinawaFwResp.
+ * @self: A [class@FwResp].
  *
- * stop to listen to a range of address in host controller.
+ * stop to listen to a range of address in local node (e.g. OHCI 1394 controller).
  *
  * Since: 1.4.
  */
@@ -324,7 +328,7 @@ void hinawa_fw_resp_release(HinawaFwResp *self)
 {
 	HinawaFwRespPrivate *priv;
 	struct fw_cdev_deallocate deallocate = {0};
-	GError *exception = NULL;
+	GError *error = NULL;
 
 	g_return_if_fail(HINAWA_IS_FW_RESP(self));
 	priv = hinawa_fw_resp_get_instance_private(self);
@@ -334,8 +338,8 @@ void hinawa_fw_resp_release(HinawaFwResp *self)
 
 	// Ignore ioctl error.
 	deallocate.handle = priv->addr_handle;
-	hinawa_fw_node_ioctl(priv->node, FW_CDEV_IOC_DEALLOCATE, &deallocate, &exception);
-	g_clear_error(&exception);
+	hinawa_fw_node_ioctl(priv->node, FW_CDEV_IOC_DEALLOCATE, &deallocate, &error);
+	g_clear_error(&error);
 	g_object_unref(priv->node);
 	priv->node = NULL;
 
@@ -354,15 +358,14 @@ void hinawa_fw_resp_release(HinawaFwResp *self)
 
 /**
  * hinawa_fw_resp_get_req_frame:
- * @self: A #HinawaFwResp
- * @frame: (array length=length)(out)(transfer none): a 8bit array for response
- * 	   frame.
+ * @self: A [class@FwResp]
+ * @frame: (array length=length)(out)(transfer none): a 8bit array for response frame.
  * @length: (out): The length of bytes for the frame.
  *
  * Retrieve byte frame to be requested.
  *
  * Since: 2.0
- * Deprecated: 2.2: handler for #HinawaFwResp::requested2 signal can receive the frame in its
+ * Deprecated: 2.2: handler for [signal@FwResp::requested2] signal can receive the frame in its
  *		    argument.
  */
 void hinawa_fw_resp_get_req_frame(HinawaFwResp *self, const guint8 **frame,
@@ -384,9 +387,8 @@ void hinawa_fw_resp_get_req_frame(HinawaFwResp *self, const guint8 **frame,
 
 /**
  * hinawa_fw_resp_set_resp_frame:
- * @self: A #HinawaFwResp
- * @frame: (element-type guint8)(array length=length): a 8bit array for response
- * 	   frame.
+ * @self: A [class@FwResp]
+ * @frame: (element-type guint8)(array length=length): a 8bit array for response frame.
  * @length: The length of bytes for the frame.
  *
  * Register byte frame as response.
@@ -418,7 +420,7 @@ void hinawa_fw_resp_handle_request(HinawaFwResp *self,
 	HinawaFwRespClass *klass;
 	struct fw_cdev_send_response resp = {0};
 	HinawaFwRcode rcode;
-	GError *exception = NULL;
+	GError *error = NULL;
 
 	g_return_if_fail(HINAWA_IS_FW_RESP(self));
 	priv = hinawa_fw_resp_get_instance_private(self);
@@ -453,6 +455,6 @@ void hinawa_fw_resp_handle_request(HinawaFwResp *self,
 	// Ignore ioctl error.
 	resp.rcode = (__u32)rcode;
 	resp.handle = event->handle;
-	hinawa_fw_node_ioctl(priv->node, FW_CDEV_IOC_SEND_RESPONSE, &resp, &exception);
-	g_clear_error(&exception);
+	hinawa_fw_node_ioctl(priv->node, FW_CDEV_IOC_SEND_RESPONSE, &resp, &error);
+	g_clear_error(&error);
 }
