@@ -1,28 +1,28 @@
-/* SPDX-License-Identifier: LGPL-2.1-or-later */
+// SPDX-License-Identifier: LGPL-2.1-or-later
+#include "internal.h"
+
 #include <string.h>
 #include <errno.h>
 
-#include "internal.h"
-#include "hinawa_sigs_marshal.h"
-
 /**
- * SECTION:snd_efw
- * @Title: HinawaSndEfw
- * @Short_description: A transaction executor for Fireworks models
- * @include: snd_efw.h
+ * HinawaSndEfw:
+ * A transaction executor for Fireworks models.
  *
- * A #HinawaSndEfw is an application of Echo Fireworks Transaction (EFT).
- * This inherits #HinawaSndUnit.
+ * A [class@SndEfw] is an application of Echo Fireworks Transaction.
+ *
+ * Deprecated: 2.5. libhitaki library provides [class@Hitaki.SndEfw] as the alternative.
  */
 
 /**
  * hinawa_snd_efw_error_quark:
  *
- * Return the GQuark for error domain of GError which has code in #HinawaSndEfwStatus.
+ * Return the [alias@GLib.Quark] for error domain of [struct@GLib.Error] which has code in
+ * [enum@SndEfwStatus].
  *
  * Since: 2.1
+ * Deprecated: 2.5. Use Hitaki.EfwProtocolError instead.
  *
- * Returns: A #GQuark.
+ * Returns: A [alias@GLib.Quark].
  */
 G_DEFINE_QUARK(hinawa-snd-efw-error-quark, hinawa_snd_efw_error)
 
@@ -49,13 +49,13 @@ static const char *const efw_status_names[] = {
 	[HINAWA_SND_EFW_STATUS_LARGE_RESP]	= "The size of response is larger than expected",
 };
 
-#define generate_local_error(exception, code)							\
-	g_set_error_literal(exception, HINAWA_SND_EFW_ERROR, code, efw_status_names[code])
+#define generate_local_error(error, code)						\
+	g_set_error_literal(error, HINAWA_SND_EFW_ERROR, code, efw_status_names[code])
 
-struct _HinawaSndEfwPrivate {
+typedef struct {
 	guint seqnum;
 	GMutex lock;
-};
+} HinawaSndEfwPrivate;
 G_DEFINE_TYPE_WITH_PRIVATE(HinawaSndEfw, hinawa_snd_efw, HINAWA_TYPE_SND_UNIT)
 
 enum efw_sig_type {
@@ -68,8 +68,8 @@ static void hinawa_snd_efw_class_init(HinawaSndEfwClass *klass)
 {
 	/**
 	 * HinawaSndEfw::responded:
-	 * @self: A #HinawaSndEfw.
-	 * @status: One of #HinawaSndEfwStatus.
+	 * @self: A [class@SndEfw].
+	 * @status: One of [enum@SndEfwStatus].
 	 * @seqnum: The sequence number of response.
 	 * @category: The value of category field in the response.
 	 * @command: The value of command field in the response.
@@ -77,17 +77,19 @@ static void hinawa_snd_efw_class_init(HinawaSndEfwClass *klass)
 	 *	   quadlet data of response for Echo Fireworks protocol.
 	 * @frame_size: The number of elements of the array.
 	 *
-	 * When the unit transfers asynchronous packet as response for Echo Audio Fireworks
-	 * protocol, and the process successfully reads the content of response from ALSA
-	 * Fireworks driver, the #HinawaSndEfw::responded signal handler is called with parameters
-	 * of the response.
+	 * Emitted when the unit transfers asynchronous packet as response for Echo Audio Fireworks
+	 * protocol, and the process successfully reads the content of response from ALSA Fireworks
+	 * driver, the [signal@SndEfw::responded] signal handler is called with parameters of the
+	 * response.
 	 *
 	 * Since: 2.1
+	 * Deprecated: 2.5. Use implementation of [class@Hitaki.SndEfw] for
+	 *	       [signal@Hitaki.EfwProtocol::responded] instead.
 	 */
 	efw_sigs[EFW_SIG_TYPE_RESPONDED] =
 		g_signal_new("responded",
 			     G_OBJECT_CLASS_TYPE(klass),
-			     G_SIGNAL_RUN_LAST,
+			     G_SIGNAL_RUN_LAST | G_SIGNAL_DEPRECATED,
 			     G_STRUCT_OFFSET(HinawaSndEfwClass, responded),
 			     NULL, NULL,
 			     hinawa_sigs_marshal_VOID__ENUM_UINT_UINT_UINT_POINTER_UINT,
@@ -103,10 +105,12 @@ static void hinawa_snd_efw_init(HinawaSndEfw *self)
 /**
  * hinawa_snd_efw_new:
  *
- * Instantiate #HinawaSndEfw object and return the instance.
+ * Instantiate [class@SndEfw] object and return the instance.
+ *
+ * Returns: an instance of [class@SndEfw].
  *
- * Returns: an instance of #HinawaSndEfw.
  * Since: 1.3.
+ * Deprecated: 2.5. Use [method@Hitaki.SndEfw.new] instead.
  */
 HinawaSndEfw *hinawa_snd_efw_new(void)
 {
@@ -115,27 +119,29 @@ HinawaSndEfw *hinawa_snd_efw_new(void)
 
 /**
  * hinawa_snd_efw_open:
- * @self: A #HinawaSndUnit
+ * @self: A [class@SndEfw]
  * @path: A full path of a special file for ALSA hwdep character device
- * @exception: A #GError. Error can be generated with three domains; #g_file_error_quark(),
- *	       #hinawa_fw_node_error_quark(), and #hinawa_snd_unit_error_quark().
+ * @error: A [struct@GLib.Error]. Error can be generated with three domains; GLib.FileError,
+ *	   Hinawa.FwNodeError, and Hinawa.SndUnitError.
  *
  * Open ALSA hwdep character device and check it for Fireworks devices.
  *
  * Since: 0.3
+ * Deprecated: 2.5. Use implementation of [method@Hitaki.AlsaFirewire.open] in
+ *	       [class@Hitaki.SndEfw] instead.
  */
-void hinawa_snd_efw_open(HinawaSndEfw *self, gchar *path, GError **exception)
+void hinawa_snd_efw_open(HinawaSndEfw *self, gchar *path, GError **error)
 {
 	HinawaSndEfwPrivate *priv;
 
 	g_return_if_fail(HINAWA_IS_SND_EFW(self));
 	g_return_if_fail(path != NULL && strlen(path) > 0);
-	g_return_if_fail(exception == NULL || *exception == NULL);
+	g_return_if_fail(error == NULL || *error == NULL);
 
 	priv = hinawa_snd_efw_get_instance_private(self);
 
-	hinawa_snd_unit_open(&self->parent_instance, path, exception);
-	if (*exception != NULL)
+	hinawa_snd_unit_open(&self->parent_instance, path, error);
+	if (*error != NULL)
 		return;
 
 	priv = hinawa_snd_efw_get_instance_private(self);
@@ -145,23 +151,26 @@ void hinawa_snd_efw_open(HinawaSndEfw *self, gchar *path, GError **exception)
 
 /**
  * hinawa_snd_efw_transaction_async:
- * @self: A #HinawaSndEfw.
+ * @self: A [class@SndEfw].
  * @category: One of category for the transaction.
  * @command: One of commands for the transaction.
  * @args: (array length=arg_count)(in)(nullable): An array with elements for quadlet data as
  *	  arguments for command.
  * @arg_count: The number of quadlets in the args array.
  * @resp_seqnum: (out): The sequence number for response transaction;
- * @exception: A #GError. Error can be generated with domain of #hinawa_snd_unit_error_quark().
+ * @error: A [struct@GLib.Error]. Error can be generated with domain of Hinawa.SndUnitError.
  *
  * Transfer asynchronous transaction for command frame of Echo Fireworks protocol. When receiving
- * asynchronous transaction for response frame, #HinawaSndEfw::responded GObject signal is emitted.
+ * asynchronous transaction for response frame, [signal@SndEfw::responded] GObject signal is
+ * emitted.
  *
  * Since: 2.1.
+ * Deprecated: 2.5. Use implementation of [method@Hitaki.EfwProtocol.transmit_request] in
+ *	       [class@Hitaki.SndEfw] instead.
  */
 void hinawa_snd_efw_transaction_async(HinawaSndEfw *self, guint category, guint command,
 				      const guint32 *args, gsize arg_count, guint32 *resp_seqnum,
-				      GError **exception)
+				      GError **error)
 {
 	HinawaSndEfwPrivate *priv;
 	struct snd_efw_transaction *frame;
@@ -171,7 +180,7 @@ void hinawa_snd_efw_transaction_async(HinawaSndEfw *self, guint category, guint
 	g_return_if_fail(HINAWA_IS_SND_EFW(self));
 	g_return_if_fail(sizeof(*args) * arg_count + sizeof(*frame) < MAXIMUM_FRAME_BYTES);
 	g_return_if_fail(resp_seqnum != NULL);
-	g_return_if_fail(exception == NULL || *exception == NULL);
+	g_return_if_fail(error == NULL || *error == NULL);
 
 	priv = hinawa_snd_efw_get_instance_private(self);
 
@@ -201,7 +210,7 @@ void hinawa_snd_efw_transaction_async(HinawaSndEfw *self, guint category, guint
 	g_mutex_unlock(&priv->lock);
 
 	// Send this request frame.
-	hinawa_snd_unit_write(&self->parent_instance, frame, quads * sizeof(__be32), exception);
+	hinawa_snd_unit_write(&self->parent_instance, frame, quads * sizeof(__be32), error);
 
 	g_free(frame);
 }
@@ -244,33 +253,34 @@ static void handle_responded_signal(HinawaSndEfw *self, HinawaSndEfwStatus statu
 
 /**
  * hinawa_snd_efw_transaction_sync:
- * @self: A #HinawaSndEfw.
+ * @self: A [class@SndEfw].
  * @category: one of category for the transaction.
  * @command: one of commands for the transaction.
- * @args: (array length=arg_count)(in)(nullable): An array with elements for
- *	  quadlet data as arguments for command.
+ * @args: (array length=arg_count)(in)(nullable): An array with elements for quadlet data as
+ *	  arguments for command.
  * @arg_count: The number of quadlets in the args array.
- * @params: (array length=param_count)(inout)(nullable): An array with elements for
- *	    quadlet data to save parameters in response. Callers should give it
- *	    for buffer with enough space against the request since this library
- *	    performs no reallocation. Due to the reason, the value of this
- *	    argument should point to the pointer to the array and immutable.
- *	    The content of array is mutable for parameters in response.
+ * @params: (array length=param_count)(inout)(nullable): An array with elements for quadlet data
+ *	    to save parameters in response. Callers should give it for buffer with enough space
+ *	    against the request since this library performs no reallocation. Due to the reason,
+ *	    the value of this argument should point to the pointer to the array and immutable. The
+ *	    content of array is mutable for parameters in response.
  * @param_count: The number of quadlets in the params array.
  * @timeout_ms: The timeout to wait for response of the transaction since request is transferred in
  *		milliseconds.
- * @exception: A #GError. Error can be generated with three domains; #hinawa_snd_unit_error_quark(),
- *	       and #hinawa_snd_efw_error_quark().
+ * @error: A [struct@GLib.Error]. Error can be generated with three domains; Hinawa.SndUnitError,
+ *	   and Hinawa.SndEfwError.
  *
  * Transfer asynchronous transaction for command frame of Echo Fireworks protocol, then wait
  * asynchronous transaction for response frame within the given timeout.
  *
  * Since: 2.1.
+ * Deprecated: 2.5. Use implementation of [method@Hitaki.EfwProtocol.transaction] in
+ *	       [class@Hitaki.SndEfw] instead.
  */
 void hinawa_snd_efw_transaction_sync(HinawaSndEfw *self, guint category, guint command,
 				     const guint32 *args, gsize arg_count,
 				     guint32 *const *params, gsize *param_count,
-				     guint timeout_ms, GError **exception)
+				     guint timeout_ms, GError **error)
 {
 	gulong handler_id;
 	struct waiter w;
@@ -278,7 +288,7 @@ void hinawa_snd_efw_transaction_sync(HinawaSndEfw *self, guint category, guint c
 
 	g_return_if_fail(HINAWA_IS_SND_EFW(self));
 	g_return_if_fail(param_count != NULL);
-	g_return_if_fail(exception == NULL || *exception == NULL);
+	g_return_if_fail(error == NULL || *error == NULL);
 
 	// This predicates against suprious wakeup.
 	w.status = 0xffffffff;
@@ -298,8 +308,8 @@ void hinawa_snd_efw_transaction_sync(HinawaSndEfw *self, guint category, guint c
 	expiration = g_get_monotonic_time() + timeout_ms * G_TIME_SPAN_MILLISECOND;
 
 	hinawa_snd_efw_transaction_async(self, category, command, args, arg_count, &w.seqnum,
-					 exception);
-	if (*exception != NULL) {
+					 error);
+	if (*error != NULL) {
 		g_signal_handler_disconnect(self, handler_id);
 		goto end;
 	}
@@ -314,11 +324,11 @@ void hinawa_snd_efw_transaction_sync(HinawaSndEfw *self, guint category, guint c
 	g_mutex_unlock(&w.mutex);
 
 	if (w.status == 0xffffffff)
-		generate_local_error(exception, HINAWA_SND_EFW_STATUS_TIMEOUT);
+		generate_local_error(error, HINAWA_SND_EFW_STATUS_TIMEOUT);
 	else if (w.status != HINAWA_SND_EFW_STATUS_OK)
-		generate_local_error(exception, w.status);
+		generate_local_error(error, w.status);
 	else if (w.param_count > *param_count)
-		generate_local_error(exception, HINAWA_SND_EFW_STATUS_LARGE_RESP);
+		generate_local_error(error, HINAWA_SND_EFW_STATUS_LARGE_RESP);
 	else
 		*param_count = w.param_count;
 end:
@@ -328,35 +338,36 @@ end:
 
 /**
  * hinawa_snd_efw_transaction:
- * @self: A #HinawaSndEfw.
+ * @self: A [class@SndEfw].
  * @category: one of category for the transaction.
  * @command: one of commands for the transaction.
- * @args: (array length=arg_count)(in)(nullable): An array with elements for
- *	  quadlet data as arguments for command.
+ * @args: (array length=arg_count)(in)(nullable): An array with elements for quadlet data as
+ *	  arguments for command.
  * @arg_count: The number of quadlets in the args array.
- * @params: (array length=param_count)(inout): An array with elements for
- *	    quadlet data to save parameters in response. Callers should give it
- *	    for buffer with enough space against the request since this library
- *	    performs no reallocation. Due to the reason, the value of this
- *	    argument should point to the pointer to the array and immutable.
- *	    The content of array is mutable for parameters in response.
+ * @params: (array length=param_count)(inout): An array with elements for quadlet data to save
+ *	    parameters in response. Callers should give it for buffer with enough space against
+ *	    the request since this library performs no reallocation. Due to the reason, the value
+ *	    of this argument should point to the pointer to the array and immutable. The content
+ *	    of array is mutable for parameters in response.
  * @param_count: The number of quadlets in the params array.
- * @exception: A #GError. Error can be generated with three domains; #hinawa_snd_unit_error_quark(),
- *	       and #hinawa_snd_efw_error_quark().
+ * @error: A [struct@GLib.Error]. Error can be generated with three domains; Hinawa.SndUnitError
+ *	   and Hinawa.SndEfwError.
  *
  * Transfer request of transaction according to Echo Fireworks Transaction protocol, then wait for
  * the response of transaction within 200 millisecond timeout.
  *
  * Since: 1.4.
+ * Deprecated: 2.5. Use implementation of [method@Hitaki.EfwProtocol.transaction] in
+ *	       [class@Hitaki.SndEfw] instead.
  */
 void hinawa_snd_efw_transaction(HinawaSndEfw *self,
 				guint category, guint command,
 				const guint32 *args, gsize arg_count,
 				guint32 *const *params, gsize *param_count,
-				GError **exception)
+				GError **error)
 {
 	hinawa_snd_efw_transaction_sync(self, category, command, args, arg_count,
-					params, param_count, 200, exception);
+					params, param_count, 200, error);
 }
 
 void hinawa_snd_efw_handle_response(HinawaSndEfw *self,
