@@ -1,4 +1,6 @@
-/* SPDX-License-Identifier: LGPL-2.1-or-later */
+// SPDX-License-Identifier: LGPL-2.1-or-later
+#include "internal.h"
+
 #include <stdio.h>
 #include <stdbool.h>
 #include <unistd.h>
@@ -10,27 +12,25 @@
 #include <sys/ioctl.h>
 #include <sys/mman.h>
 
-#include "internal.h"
-#include "hinawa_enums.h"
-
 /**
- * SECTION:snd_unit
- * @Title: HinawaSndUnit
- * @Short_description: An event listener for ALSA FireWire sound devices
- * @include: snd_unit.h
+ * HinawaSndUnit:
+ * An event listener for ALSA FireWire sound devices.
  *
- * This class is an application of ALSA FireWire stack. Any functionality which
- * ALSA drivers in the stack can be available.
+ * This class is an application of ALSA FireWire stack. Any functionality which ALSA drivers in the
+ * stack can be available.
+ *
+ * Deprecated: 2.5. libhitaki library provides [class@Hitaki.SndUnit] as the alternative.
  */
 
 /**
  * hinawa_snd_unit_error_quark:
  *
- * Return the GQuark for error domain of GError which has code in #HinawaSndUnitError.
+ * Return the [alias@GLib.Quark] for [struct@GLib.Error] which has code in Hinawa.SndUnitError.
  *
  * Since: 2.1
+ * Deprecated: 2.5. Use Hitaki.AlsaFirewireError instead.
  *
- * Returns: A #GQuark.
+ * Returns: A [alias@GLib.Quark].
  */
 G_DEFINE_QUARK(hinawa-snd-unit-error-quark, hinawa_snd_unit_error)
 
@@ -44,23 +44,23 @@ static const char *const err_msgs[] = {
 	[HINAWA_SND_UNIT_ERROR_WRONG_CLASS] = "The hwdep device is not for the unit expected by the class",
 };
 
-#define generate_local_error(exception, code) \
-	g_set_error_literal(exception, HINAWA_FW_NODE_ERROR, code, err_msgs[code])
+#define generate_local_error(error, code) \
+	g_set_error_literal(error, HINAWA_FW_NODE_ERROR, code, err_msgs[code])
 
-#define generate_file_error(exception, code, format, arg) \
-	g_set_error(exception, G_FILE_ERROR, code, format, arg)
+#define generate_file_error(error, code, format, arg) \
+	g_set_error(error, G_FILE_ERROR, code, format, arg)
 
-#define generate_syscall_error(exception, errno, format, arg)				\
-	g_set_error(exception, HINAWA_SND_UNIT_ERROR, HINAWA_SND_UNIT_ERROR_FAILED,	\
+#define generate_syscall_error(error, errno, format, arg)			\
+	g_set_error(error, HINAWA_SND_UNIT_ERROR, HINAWA_SND_UNIT_ERROR_FAILED,	\
 		    format " %d(%s)", arg, errno, strerror(errno))
 
-struct _HinawaSndUnitPrivate {
+typedef struct {
 	int fd;
 	struct snd_firewire_get_info info;
 	HinawaFwNode *node;
 
 	gboolean streaming;
-};
+} HinawaSndUnitPrivate;
 G_DEFINE_TYPE_WITH_PRIVATE(HinawaSndUnit, hinawa_snd_unit, G_TYPE_OBJECT)
 
 typedef struct {
@@ -142,59 +142,64 @@ static void hinawa_snd_unit_class_init(HinawaSndUnitClass *klass)
 	 * HinawaSndUnit:type:
 	 *
 	 * Since: 1.0
+	 * Deprecated: 2.5. Use [property@Hitaki.AlsaFirewire:unit-type] instead.
 	 */
 	snd_unit_props[SND_UNIT_PROP_TYPE_FW_TYPE] =
 		g_param_spec_enum("type", "type",
 				  "The value of HinawaSndUnitType enumerators",
 				  HINAWA_TYPE_SND_UNIT_TYPE,
 				  HINAWA_SND_UNIT_TYPE_DICE,
-				  G_PARAM_READABLE);
+				  G_PARAM_READABLE | G_PARAM_DEPRECATED);
 
 	/**
 	 * HinawaSndUnit:card:
 	 *
 	 * Since: 2.0
+	 * Deprecated: 2.5. Use [property@Hitaki.AlsaFirewire:card_id] instead.
 	 */
 	snd_unit_props[SND_UNIT_PROP_TYPE_CARD_ID] =
 		g_param_spec_uint("card", "card",
 				  "The numeric ID for ALSA sound card",
 				  0, G_MAXUINT,
 				  0,
-				  G_PARAM_READABLE);
+				  G_PARAM_READABLE | G_PARAM_DEPRECATED);
 
 	/**
 	 * HinawaSndUnit:device:
 	 *
 	 *
 	 * Since: 0.3
+	 * Deprecated: 2.5. Use [property@Hitaki.AlsaFirewire:node-device] instead.
 	 */
 	snd_unit_props[SND_UNIT_PROP_TYPE_DEVICE] =
 		g_param_spec_string("device", "device",
 				    "A name of special file as FireWire unit.",
 				    NULL,
-				    G_PARAM_READABLE);
+				    G_PARAM_READABLE | G_PARAM_DEPRECATED);
 
 	/**
 	 * HinawaSndUnit:streaming:
 	 *
 	 * Since: 0.4
+	 * Deprecated: 2.5. Use [property@Hitaki.AlsaFirewire:is-locked] instead.
 	 */
 	snd_unit_props[SND_UNIT_PROP_TYPE_STREAMING] =
 		g_param_spec_boolean("streaming", "streaming",
 				     "Whether this device is streaming or not",
 				     FALSE,
-				     G_PARAM_READABLE);
+				     G_PARAM_READABLE | G_PARAM_DEPRECATED);
 
 	/**
 	 * HinawaSndUnit:guid:
 	 *
 	 * Since: 0.4
+	 * Deprecated: 2.5. Use [property@Hitaki.AlsaFirewire:guid] instead.
 	 */
 	snd_unit_props[SND_UNIT_PROP_TYPE_GUID] =
 		g_param_spec_uint64("guid", "guid",
 				    "Global unique ID for this firewire unit.",
 				    0, G_MAXUINT64, 0,
-				    G_PARAM_READABLE);
+				    G_PARAM_READABLE | G_PARAM_DEPRECATED);
 
 	g_object_class_install_properties(gobject_class,
 					  SND_UNIT_PROP_TYPE_COUNT,
@@ -202,18 +207,20 @@ static void hinawa_snd_unit_class_init(HinawaSndUnitClass *klass)
 
 	/**
 	 * HinawaSndUnit::lock-status:
-	 * @self: A #HinawaSndUnit
+	 * @self: A [class@SndUnit]
 	 * @state: %TRUE when locked, %FALSE when unlocked.
 	 *
-	 * When ALSA kernel-streaming status is changed, this #HinawaSndUnit::lock-status
-	 * signal is generated.
+	 * Emitted when corresponding ALSA driver changes status of lock by starting/stopping
+	 * packet streaming requested by ALSA PCM/Rawmidi applications.
 	 *
 	 * Since: 0.3
+	 * Deprecated: 2.5. Use change notify signal of [property@Hitaki.AlsaFirewire:is-locked]
+	 *	       instead.
 	 */
 	snd_unit_sigs[SND_UNIT_SIG_TYPE_LOCK_STATUS] =
 		g_signal_new("lock-status",
 			     G_OBJECT_CLASS_TYPE(klass),
-			     G_SIGNAL_RUN_LAST,
+			     G_SIGNAL_RUN_LAST | G_SIGNAL_DEPRECATED,
 			     G_STRUCT_OFFSET(HinawaSndUnitClass, lock_status),
 			     NULL, NULL,
 			     g_cclosure_marshal_VOID__BOOLEAN,
@@ -221,19 +228,20 @@ static void hinawa_snd_unit_class_init(HinawaSndUnitClass *klass)
 
 	/**
 	 * HinawaSndUnit::disconnected:
-	 * @self: A #HinawaSndUnit
+	 * @self: A [class@SndUnit]
 	 *
-	 * When the sound card is not available anymore due to unbinding driver
-	 * or hot unplugging, this signal is emit. The owner of this object
-	 * should call g_object_free() as quickly as possible to release ALSA
-	 * hwdep character device.
+	 * Emitted when the sound card is not available anymore due to unbinding driver or hot
+	 * unplugging. The owner of this object should call [method@GObject.Object.unref] as
+	 * quickly as possible to release ALSA hwdep character device.
 	 *
 	 * Since: 2.0
+	 * Deprecated: 2.5. Use change notify signal of
+	 *	       [property@Hitaki.AlsaFirewire:is-disconnected] instead.
 	 */
 	snd_unit_sigs[SND_UNIT_SIG_TYPE_DISCONNECTED] =
 		g_signal_new("disconnected",
 			     G_OBJECT_CLASS_TYPE(klass),
-			     G_SIGNAL_RUN_LAST,
+			     G_SIGNAL_RUN_LAST | G_SIGNAL_DEPRECATED,
 			     G_STRUCT_OFFSET(HinawaSndUnitClass, disconnected),
 			     NULL, NULL,
 			     g_cclosure_marshal_VOID__VOID,
@@ -251,10 +259,12 @@ static void hinawa_snd_unit_init(HinawaSndUnit *self)
 /**
  * hinawa_snd_unit_new:
  *
- * Instantiate #HinawaSndUnit object and return the instance.
+ * Instantiate [class@SndUnit] object and return the instance.
+ *
+ * Returns: an instance of [class@SndUnit].
  *
- * Returns: an instance of #HinawaSndUnit.
  * Since: 1.3.
+ * Deprecated: 2.5. Use [method@Hitaki.SndUnit.new] instead.
  */
 HinawaSndUnit *hinawa_snd_unit_new(void)
 {
@@ -263,43 +273,45 @@ HinawaSndUnit *hinawa_snd_unit_new(void)
 
 /**
  * hinawa_snd_unit_open:
- * @self: A #HinawaSndUnit
+ * @self: A [class@SndUnit]
  * @path: A full path of a special file for ALSA hwdep character device
- * @exception: A #GError. Error can be generated with three domains; #g_file_error_quark(),
- *	       #hinawa_fw_node_error_quark(), and #hinawa_snd_unit_error_quark().
+ * @error: A [struct@GLib.Error]. Error can be generated with three domains; GLib.FileError,
+ *	   Hinawa.FwNodeError, and Hinawa.SndUnitError.
  *
  * Open ALSA hwdep character device and check it for FireWire sound devices.
  *
  * Since: 0.4
+ * Deprecated: 2.5. Use implementation of [method@Hitaki.AlsaFirewire.open] in
+ *	       [class@Hitaki.SndUnit] instead.
  */
-void hinawa_snd_unit_open(HinawaSndUnit *self, gchar *path, GError **exception)
+void hinawa_snd_unit_open(HinawaSndUnit *self, gchar *path, GError **error)
 {
 	HinawaSndUnitPrivate *priv;
 	char fw_cdev[32];
 
 	g_return_if_fail(HINAWA_IS_SND_UNIT(self));
 	g_return_if_fail(path != NULL && strlen(path) > 0);
-	g_return_if_fail(exception == NULL || *exception == NULL);
+	g_return_if_fail(error == NULL || *error == NULL);
 
 	priv = hinawa_snd_unit_get_instance_private(self);
 	if (priv->fd >= 0) {
-		generate_local_error(exception, HINAWA_SND_UNIT_ERROR_OPENED);
+		generate_local_error(error, HINAWA_SND_UNIT_ERROR_OPENED);
 		return;
 	}
 
 	priv->fd = open(path, O_RDWR);
 	if (priv->fd < 0) {
 		if (errno == ENODEV) {
-			generate_local_error(exception, HINAWA_SND_UNIT_ERROR_DISCONNECTED);
+			generate_local_error(error, HINAWA_SND_UNIT_ERROR_DISCONNECTED);
 		} else if (errno == EBUSY) {
-			generate_local_error(exception, HINAWA_SND_UNIT_ERROR_USED);
+			generate_local_error(error, HINAWA_SND_UNIT_ERROR_USED);
 		} else {
 			GFileError code = g_file_error_from_errno(errno);
 
 			if (code != G_FILE_ERROR_FAILED)
-				generate_file_error(exception, code, "open(%s)", path);
+				generate_file_error(error, code, "open(%s)", path);
 			else
-				generate_syscall_error(exception, errno, "open(%s)", path);
+				generate_syscall_error(error, errno, "open(%s)", path);
 		}
 		return;
 	}
@@ -307,36 +319,36 @@ void hinawa_snd_unit_open(HinawaSndUnit *self, gchar *path, GError **exception)
 	/* Get FireWire sound device information. */
 	if (ioctl(priv->fd, SNDRV_FIREWIRE_IOCTL_GET_INFO, &priv->info) < 0) {
 		if (errno == ENODEV)
-			generate_local_error(exception, HINAWA_SND_UNIT_ERROR_DISCONNECTED);
+			generate_local_error(error, HINAWA_SND_UNIT_ERROR_DISCONNECTED);
 		else
-			generate_syscall_error(exception, errno, "ioctl(%s)", "SNDRV_FIREWIRE_IOCTL_GET_INFO");
+			generate_syscall_error(error, errno, "ioctl(%s)", "SNDRV_FIREWIRE_IOCTL_GET_INFO");
 		goto end;
 	}
 
 	if (HINAWA_IS_SND_DICE(self) && priv->info.type != SNDRV_FIREWIRE_TYPE_DICE) {
-		generate_local_error(exception, HINAWA_SND_UNIT_ERROR_WRONG_CLASS);
+		generate_local_error(error, HINAWA_SND_UNIT_ERROR_WRONG_CLASS);
 		goto end;
 	}
 	if (HINAWA_IS_SND_EFW(self) && priv->info.type != SNDRV_FIREWIRE_TYPE_FIREWORKS) {
-		generate_local_error(exception, HINAWA_SND_UNIT_ERROR_WRONG_CLASS);
+		generate_local_error(error, HINAWA_SND_UNIT_ERROR_WRONG_CLASS);
 		goto end;
 	}
 	if (HINAWA_IS_SND_DG00X(self) && priv->info.type != SNDRV_FIREWIRE_TYPE_DIGI00X) {
-		generate_local_error(exception, HINAWA_SND_UNIT_ERROR_WRONG_CLASS);
+		generate_local_error(error, HINAWA_SND_UNIT_ERROR_WRONG_CLASS);
 		goto end;
 	}
 	if (HINAWA_IS_SND_MOTU(self) && priv->info.type != SNDRV_FIREWIRE_TYPE_MOTU) {
-		generate_local_error(exception, HINAWA_SND_UNIT_ERROR_WRONG_CLASS);
+		generate_local_error(error, HINAWA_SND_UNIT_ERROR_WRONG_CLASS);
 		goto end;
 	}
 	if (HINAWA_IS_SND_TSCM(self) && priv->info.type != SNDRV_FIREWIRE_TYPE_TASCAM) {
-		generate_local_error(exception, HINAWA_SND_UNIT_ERROR_WRONG_CLASS);
+		generate_local_error(error, HINAWA_SND_UNIT_ERROR_WRONG_CLASS);
 		goto end;
 	}
 	snprintf(fw_cdev, sizeof(fw_cdev), "/dev/%s", priv->info.device_name);
-	hinawa_fw_node_open(priv->node, fw_cdev, exception);
+	hinawa_fw_node_open(priv->node, fw_cdev, error);
 end:
-	if (*exception != NULL) {
+	if (*error != NULL) {
 		close(priv->fd);
 		priv->fd = -1;
 	}
@@ -344,12 +356,14 @@ end:
 
 /**
  * hinawa_snd_unit_get_node:
- * @self: A #HinawaSndUnit.
- * @node: (out)(transfer none): A #HinawaFwNode.
+ * @self: A [class@SndUnit].
+ * @node: (out)(transfer none): A [class@FwNode].
  *
- * Retrieve an instance of #HinawaFwNode associated to the given unit.
+ * Retrieve an instance of [class@FwNode] associated to the given unit.
  *
  * Since: 2.0.
+ * Deprecated: 2.5. Instantiate [class@FwNode] according to
+ *	       [property@Hitaki.AlsaFirewire:node-device] instead.
  */
 void hinawa_snd_unit_get_node(HinawaSndUnit *self, HinawaFwNode **node)
 {
@@ -365,112 +379,116 @@ void hinawa_snd_unit_get_node(HinawaSndUnit *self, HinawaFwNode **node)
 }
 /**
  * hinawa_snd_unit_lock:
- * @self: A #HinawaSndUnit
- * @exception: A #GError. Error can be generated with domain of #hinawa_snd_unit_error_quark().
+ * @self: A [class@SndUnit]
+ * @error: A [struct@GLib.Error]. Error can be generated with domain of Hinawa.SndUnitError.
  *
- * Disallow ALSA to start kernel-streaming.
+ * Disallow corresponding ALSA driver to start packet streaming.
  *
  * Since: 0.3
+ * Deprecated: 2.5. Use implementation of [method@Hitaki.AlsaFirewire.lock] in
+ *	       [class@Hitaki.SndUnit] instead.
  */
-void hinawa_snd_unit_lock(HinawaSndUnit *self, GError **exception)
+void hinawa_snd_unit_lock(HinawaSndUnit *self, GError **error)
 {
 	HinawaSndUnitPrivate *priv;
 
 	g_return_if_fail(HINAWA_IS_SND_UNIT(self));
-	g_return_if_fail(exception == NULL || *exception == NULL);
+	g_return_if_fail(error == NULL || *error == NULL);
 
 	priv = hinawa_snd_unit_get_instance_private(self);
 	if (priv->fd < 0) {
-		generate_local_error(exception, HINAWA_SND_UNIT_ERROR_NOT_OPENED);
+		generate_local_error(error, HINAWA_SND_UNIT_ERROR_NOT_OPENED);
 		return;
 	}
 
 	if (ioctl(priv->fd, SNDRV_FIREWIRE_IOCTL_LOCK, NULL) < 0) {
 		if (errno == ENODEV)
-			generate_local_error(exception, HINAWA_SND_UNIT_ERROR_DISCONNECTED);
+			generate_local_error(error, HINAWA_SND_UNIT_ERROR_DISCONNECTED);
 		else if (errno == EBUSY)
-			generate_local_error(exception, HINAWA_SND_UNIT_ERROR_LOCKED);
+			generate_local_error(error, HINAWA_SND_UNIT_ERROR_LOCKED);
 		else
-			generate_syscall_error(exception, errno, "ioctl(%s)", "SNDRV_FIREWIRE_IOCTL_LOCK");
+			generate_syscall_error(error, errno, "ioctl(%s)", "SNDRV_FIREWIRE_IOCTL_LOCK");
 	}
 }
 
 /**
  * hinawa_snd_unit_unlock:
- * @self: A #HinawaSndUnit
- * @exception: A #GError. Error can be generated with domain of #hinawa_snd_unit_error_quark().
+ * @self: A [class@SndUnit]
+ * @error: A [struct@GLib.Error]. Error can be generated with domain of Hinawa.SndUnitError.
  *
- * Allow ALSA to start kernel-streaming.
+ * Allow corresponding ALSA driver to start packet streaming.
  *
  * Since: 0.3
+ * Deprecated: 2.5. Use implementation of [method@Hitaki.AlsaFirewire.unlock] in
+ *	       [class@Hitaki.SndUnit] instead.
  */
-void hinawa_snd_unit_unlock(HinawaSndUnit *self, GError **exception)
+void hinawa_snd_unit_unlock(HinawaSndUnit *self, GError **error)
 {
 	HinawaSndUnitPrivate *priv;
 
 	g_return_if_fail(HINAWA_IS_SND_UNIT(self));
-	g_return_if_fail(exception == NULL || *exception == NULL);
+	g_return_if_fail(error == NULL || *error == NULL);
 
 	priv = hinawa_snd_unit_get_instance_private(self);
 	if (priv->fd < 0) {
-		generate_local_error(exception, HINAWA_SND_UNIT_ERROR_NOT_OPENED);
+		generate_local_error(error, HINAWA_SND_UNIT_ERROR_NOT_OPENED);
 		return;
 	}
 
 	if (ioctl(priv->fd, SNDRV_FIREWIRE_IOCTL_UNLOCK, NULL) < 0) {
 		if (errno == ENODEV)
-			generate_local_error(exception, HINAWA_SND_UNIT_ERROR_DISCONNECTED);
+			generate_local_error(error, HINAWA_SND_UNIT_ERROR_DISCONNECTED);
 		else if (errno == EBADFD)
-			generate_local_error(exception, HINAWA_SND_UNIT_ERROR_UNLOCKED);
+			generate_local_error(error, HINAWA_SND_UNIT_ERROR_UNLOCKED);
 		else
-			generate_syscall_error(exception, errno, "ioctl(%s)", "SNDRV_FIREWIRE_IOCTL_UNLOCK");
+			generate_syscall_error(error, errno, "ioctl(%s)", "SNDRV_FIREWIRE_IOCTL_UNLOCK");
 	}
 }
 
 /* For internal use. */
 void hinawa_snd_unit_write(HinawaSndUnit *self, const void *buf, size_t length,
-			   GError **exception)
+			   GError **error)
 {
 	HinawaSndUnitPrivate *priv;
 	ssize_t len;
 
 	g_return_if_fail(HINAWA_IS_SND_UNIT(self));
-	g_return_if_fail(exception == NULL || *exception == NULL);
+	g_return_if_fail(error == NULL || *error == NULL);
 
 	priv = hinawa_snd_unit_get_instance_private(self);
 	if (priv->fd < 0) {
-		generate_local_error(exception, HINAWA_SND_UNIT_ERROR_NOT_OPENED);
+		generate_local_error(error, HINAWA_SND_UNIT_ERROR_NOT_OPENED);
 		return;
 	}
 
 	len = write(priv->fd, buf, length);
 	if (len < 0) {
 		if (errno == ENODEV)
-			generate_local_error(exception, HINAWA_SND_UNIT_ERROR_DISCONNECTED);
+			generate_local_error(error, HINAWA_SND_UNIT_ERROR_DISCONNECTED);
 		else
-			generate_syscall_error(exception, errno, "write: %zu", length);
+			generate_syscall_error(error, errno, "write: %zu", length);
 	} else if (len != length){
-		generate_syscall_error(exception, EIO, "write: %zu", length);
+		generate_syscall_error(error, EIO, "write: %zu", length);
 	}
 }
 
 void hinawa_snd_unit_ioctl(HinawaSndUnit *self, unsigned long request,
-			   void *arg, GError **exception)
+			   void *arg, GError **error)
 {
 	HinawaSndUnitPrivate *priv;
 
 	g_return_if_fail(HINAWA_IS_SND_UNIT(self));
-	g_return_if_fail(exception == NULL || *exception == NULL);
+	g_return_if_fail(error == NULL || *error == NULL);
 
 	priv = hinawa_snd_unit_get_instance_private(self);
 	if (priv->fd < 0) {
-		generate_local_error(exception, HINAWA_SND_UNIT_ERROR_NOT_OPENED);
+		generate_local_error(error, HINAWA_SND_UNIT_ERROR_NOT_OPENED);
 		return;
 	}
 
 	if (ioctl(priv->fd, request, arg) < 0) {
 		if (errno == ENODEV) {
-			generate_local_error(exception, HINAWA_SND_UNIT_ERROR_DISCONNECTED);
+			generate_local_error(error, HINAWA_SND_UNIT_ERROR_DISCONNECTED);
 		} else {
 			const char *arg;
 
@@ -492,7 +510,7 @@ void hinawa_snd_unit_ioctl(HinawaSndUnit *self, unsigned long request,
 				break;
 			}
 
-			generate_syscall_error(exception, errno, "ioctl(%s)", arg);
+			generate_syscall_error(error, errno, "ioctl(%s)", arg);
 		}
 	}
 }
@@ -514,7 +532,7 @@ static gboolean check_src(GSource *gsrc)
 	SndUnitSource *src = (SndUnitSource *)gsrc;
 	GIOCondition condition;
 
-	// Don't go to dispatch if nothing available. As an exception, return
+	// Don't go to dispatch if nothing available. As an error, return
 	// TRUE for POLLERR to call .dispatch for internal destruction.
 	condition = g_source_query_unix_fd(gsrc, src->tag);
 	return !!(condition & (G_IO_IN | G_IO_ERR));
@@ -594,16 +612,19 @@ static void finalize_src(GSource *gsrc)
 
 /**
  * hinawa_snd_unit_create_source:
- * @self: A #HinawaSndUnit.
- * @gsrc: (out): A #GSource.
- * @exception: A #GError. Error can be generated with domain with #hinawa_snd_unit_error_quark().
+ * @self: A [class@SndUnit].
+ * @gsrc: (out): A [struct@GLib.Source].
+ * @error: A [struct@GLib.Error]. Error can be generated with domain with Hinawa.SndUnitError.
  *
- * Create Gsource for GMainContext to dispatch events for the sound device.
+ * Create [struct@GLib.Source] for [struct@GLib.MainContext] to dispatch events for the sound
+ * device.
  *
  * Since: 1.4.
+ * Deprecated: 2.5. Use implementation of [method@Hitaki.AlsaFirewire.create_source] in
+ *	       [class@Hitaki.SndUnit] instead.
  */
 void hinawa_snd_unit_create_source(HinawaSndUnit *self, GSource **gsrc,
-				   GError **exception)
+				   GError **error)
 {
 	static GSourceFuncs funcs = {
 		.check		= check_src,
@@ -615,11 +636,11 @@ void hinawa_snd_unit_create_source(HinawaSndUnit *self, GSource **gsrc,
 
 	g_return_if_fail(HINAWA_IS_SND_UNIT(self));
 	g_return_if_fail(gsrc != NULL);
-	g_return_if_fail(exception == NULL || *exception == NULL);
+	g_return_if_fail(error == NULL || *error == NULL);
 
 	priv = hinawa_snd_unit_get_instance_private(self);
 	if (priv->fd < 0) {
-		generate_local_error(exception, HINAWA_SND_UNIT_ERROR_NOT_OPENED);
+		generate_local_error(error, HINAWA_SND_UNIT_ERROR_NOT_OPENED);
 		return;
 	}
 
